/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _DATESELECT_H_
#define _DATESELECT_H_

#include<libglademm.h>
#include<gtkmm.h>

class TDateSelect
{
    public:
		TDateSelect();
		virtual ~TDateSelect();
	
		/// This function should be used to show the date selection dialog.
        /// \param parent - parent window to be set transient for
        /// \param resultDate - the reference to the date container
        ///            where the selection result will be stored to
        /// \param title - the dialog title
        /// \param label - the query label
        /// \param defaultDate - the default date to be selected initially
        /// \returns true if the user have selected the date and clicked OK
        bool getDateSelection(Gtk::Window* parent,
                              Glib::Date& resultDate,
                              const Glib::ustring title,
                              const Glib::ustring label,
                              const Glib::Date* defaultDate = 0);
	
	private:
        // semaphore
        bool isDateSelecting;
    
        // signal handlers
        void on_date_selection_double_click();
        void on_calendar_date_selected();
        void on_day_change();
        void on_month_change();
        void on_year_change();

        // component references
        Gtk::Dialog* pDateSelectionDialog;
        Gtk::Calendar* pDateSelectionDialogCalendar;
        Gtk::SpinButton* daySpinButton;
        Gtk::SpinButton* monthSpinButton;
        Gtk::SpinButton* yearSpinButton;
        Gtk::Label* pDateSelectionDialogLabel;
        Gtk::HButtonBox* mainButtonBox;
        Gtk::Button* OKButton;
};

#endif	//_DATESELECT_H_
